==> openttd-1.9.0-beta1-docs.tar.tar: openttd-1.9.0-beta1-docs/html/d9/dc3/tree__cmd_8cpp.js <==
var tree__cmd_8cpp =
[
    [ "TreeListEnt", "d0/dcf/structTreeListEnt.html", "d0/dcf/structTreeListEnt" ],
    [ "ExtraTreePlacement", "d9/dc3/tree__cmd_8cpp.html#a2b76dd1423879348f387dcd71a0d1a64", [
      [ "ETP_NONE", "d9/dc3/tree__cmd_8cpp.html#a2b76dd1423879348f387dcd71a0d1a64a6ec3f573368d56467c9bda3892f668a4", null ],
      [ "ETP_RAINFOREST", "d9/dc3/tree__cmd_8cpp.html#a2b76dd1423879348f387dcd71a0d1a64a2c76b0f93244768aeda727fbe126d877", null ],
      [ "ETP_ALL", "d9/dc3/tree__cmd_8cpp.html#a2b76dd1423879348f387dcd71a0d1a64a0a0f44427c546612f22ff6946442efb7", null ]
    ] ],
    [ "TreePlacer", "d9/dc3/tree__cmd_8cpp.html#a62976aba58d082b1c77364dd6c9c9033", [
      [ "TP_NONE", "d9/dc3/tree__cmd_8cpp.html#a62976aba58d082b1c77364dd6c9c9033a2d0ba850116456076d03569a92908d23", null ],
      [ "TP_ORIGINAL", "d9/dc3/tree__cmd_8cpp.html#a62976aba58d082b1c77364dd6c9c9033a829990135d9b8605a8ee43660e66d2bd", null ],
      [ "TP_IMPROVED", "d9/dc3/tree__cmd_8cpp.html#a62976aba58d082b1c77364dd6c9c9033a256218c06725b5b60ee90a5f2c0e7653", null ]
    ] ],
    [ "CanPlantTreesOnTile", "d9/dc3/tree__cmd_8cpp.html#a5d042da17079f9012fdac1e3df9731d8", null ],
    [ "ChangeTileOwner_Trees", "d9/dc3/tree__cmd_8cpp.html#a995381cf503eb25e14608d26519a36f0", null ],
    [ "ClearTile_Trees", "d9/dc3/tree__cmd_8cpp.html#ae1cdf143851717267cb827c29c7947ec", null ],
    [ "CmdPlantTree", "d9/dc3/tree__cmd_8cpp.html#ae8db8a301d3b952f48caf6c0fae6bf3b", null ],
    [ "DrawTile_Trees", "d9/dc3/tree__cmd_8cpp.html#a40f0c4d6d9e426e37032515fe6a0ab89", null ],
    [ "GenerateTrees", "d9/dc3/tree__cmd_8cpp.html#a3c422e87386100322f3148c214146dd8", null ],
    [ "GetFoundation_Trees", "d9/dc3/tree__cmd_8cpp.html#a5815d0fa4faf01ed130e6d1d68120ec4", null ],
    [ "GetRandomTreeType", "d9/dc3/tree__cmd_8cpp.html#a269149b13fc8cd41fa9ad52b3d778e3b", null ],
    [ "GetSlopePixelZ_Trees", "d9/dc3/tree__cmd_8cpp.html#ad05dc20531ce49ee6b27e8151f6d2b55", null ],
    [ "GetTileDesc_Trees", "d9/dc3/tree__cmd_8cpp.html#ada0e9fe8b6e5802c78ce321cc10a9445", null ],
    [ "GetTileTrackStatus_Trees", "d9/dc3/tree__cmd_8cpp.html#a825c17a2dd5be07f4ff672f799a26630", null ],
    [ "InitializeTrees", "d9/dc3/tree__cmd_8cpp.html#a936045bf466edc257d0a8b84808c7811", null ],
    [ "OnTick_Trees", "d9/dc3/tree__cmd_8cpp.html#a91716e26a7385ebc4cc838da245a039d", null ],
    [ "PlaceTree", "d9/dc3/tree__cmd_8cpp.html#a943fb392a1ca2eec997e04976acf2fce", null ],
    [ "PlaceTreeAtSameHeight", "d9/dc3/tree__cmd_8cpp.html#aae0d2348b670be4ef512d4b0c7344324", null ],
    [ "PlaceTreeGroups", "d9/dc3/tree__cmd_8cpp.html#adbe6ff54c3d93cdc576ac5ccc4cbde75", null ],
    [ "PlaceTreesRandomly", "d9/dc3/tree__cmd_8cpp.html#a65f3e742e983737d751924e51c619587", null ],
    [ "PlantTreesOnTile", "d9/dc3/tree__cmd_8cpp.html#a55463c9ed13541b340bdd252327d5481", null ],
    [ "TerraformTile_Trees", "d9/dc3/tree__cmd_8cpp.html#a91e0942ef786380c992910d25e8e5b87", null ],
    [ "TileLoop_Trees", "d9/dc3/tree__cmd_8cpp.html#afb76385f7dfcce77b0d24754d0638aa2", null ],
    [ "TileLoopTreesAlps", "d9/dc3/tree__cmd_8cpp.html#a1a3dc73e2e6dcc15c3e853f7023a6e51", null ],
    [ "TileLoopTreesDesert", "d9/dc3/tree__cmd_8cpp.html#a20afb620e9d6164e65ba69018cc49a32", null ],
    [ "_tile_type_trees_procs", "d9/dc3/tree__cmd_8cpp.html#a1db92fe41eb6e62674ddcd96bfbb3cbc", null ],
    [ "_trees_tick_ctr", "d9/dc3/tree__cmd_8cpp.html#a296398b4ff7ff148567927f6c2ecdef6", null ],
    [ "DEFAULT_RAINFOREST_TREE_STEPS", "d9/dc3/tree__cmd_8cpp.html#a10064b0500651e1beb92d77e1dabee60", null ],
    [ "DEFAULT_TREE_STEPS", "d9/dc3/tree__cmd_8cpp.html#a55d4e8ebce8f6d1d857ef20e92893baa", null ],
    [ "EDITOR_TREE_DIV", "d9/dc3/tree__cmd_8cpp.html#a63aab7ec759ec6fe162ec898a98981b0", null ]
];

==> openttd-1.11.0-beta1-docs.tar.tar: openttd-1.11.0-beta1-docs/html/d9/dc3/tree__cmd_8cpp.js <==
var tree__cmd_8cpp =
[
    [ "TreeListEnt", "d0/dcf/structTreeListEnt.html", "d0/dcf/structTreeListEnt" ],
    [ "ExtraTreePlacement", "d9/dc3/tree__cmd_8cpp.html#a2b76dd1423879348f387dcd71a0d1a64", [
      [ "ETP_NO_SPREAD", "d9/dc3/tree__cmd_8cpp.html#a2b76dd1423879348f387dcd71a0d1a64ab21c2d2741f50d59543e158494915527", null ],
      [ "ETP_SPREAD_RAINFOREST", "d9/dc3/tree__cmd_8cpp.html#a2b76dd1423879348f387dcd71a0d1a64a7bfe0155b603296c8e0ab2c7c725ec10", null ],
      [ "ETP_SPREAD_ALL", "d9/dc3/tree__cmd_8cpp.html#a2b76dd1423879348f387dcd71a0d1a64af9a94f086999efe9d839d2cbabaf6f63", null ],
      [ "ETP_NO_GROWTH_NO_SPREAD", "d9/dc3/tree__cmd_8cpp.html#a2b76dd1423879348f387dcd71a0d1a64ad9f0a72c140452fef0a341905e5e15ef", null ]
    ] ],
    [ "TreePlacer", "d9/dc3/tree__cmd_8cpp.html#a62976aba58d082b1c77364dd6c9c9033", [
      [ "TP_NONE", "d9/dc3/tree__cmd_8cpp.html#a62976aba58d082b1c77364dd6c9c9033a2d0ba850116456076d03569a92908d23", null ],
      [ "TP_ORIGINAL", "d9/dc3/tree__cmd_8cpp.html#a62976aba58d082b1c77364dd6c9c9033a829990135d9b8605a8ee43660e66d2bd", null ],
      [ "TP_IMPROVED", "d9/dc3/tree__cmd_8cpp.html#a62976aba58d082b1c77364dd6c9c9033a256218c06725b5b60ee90a5f2c0e7653", null ]
    ] ],
    [ "CanPlantExtraTrees", "d9/dc3/tree__cmd_8cpp.html#ae7419e6ae1ffe74825414fe0ed8b5662", null ],
    [ "CanPlantTreesOnTile", "d9/dc3/tree__cmd_8cpp.html#a5d042da17079f9012fdac1e3df9731d8", null ],
    [ "ChangeTileOwner_Trees", "d9/dc3/tree__cmd_8cpp.html#a995381cf503eb25e14608d26519a36f0", null ],
    [ "ClearTile_Trees", "d9/dc3/tree__cmd_8cpp.html#ae1cdf143851717267cb827c29c7947ec", null ],
    [ "CmdPlantTree", "d9/dc3/tree__cmd_8cpp.html#ae8db8a301d3b952f48caf6c0fae6bf3b", null ],
    [ "DrawTile_Trees", "d9/dc3/tree__cmd_8cpp.html#a40f0c4d6d9e426e37032515fe6a0ab89", null ],
    [ "GenerateTrees", "d9/dc3/tree__cmd_8cpp.html#a3c422e87386100322f3148c214146dd8", null ],
    [ "GetFoundation_Trees", "d9/dc3/tree__cmd_8cpp.html#a5815d0fa4faf01ed130e6d1d68120ec4", null ],
    [ "GetRandomTreeType", "d9/dc3/tree__cmd_8cpp.html#a269149b13fc8cd41fa9ad52b3d778e3b", null ],
    [ "GetSlopePixelZ_Trees", "d9/dc3/tree__cmd_8cpp.html#ad05dc20531ce49ee6b27e8151f6d2b55", null ],
    [ "GetTileDesc_Trees", "d9/dc3/tree__cmd_8cpp.html#ada0e9fe8b6e5802c78ce321cc10a9445", null ],
    [ "GetTileTrackStatus_Trees", "d9/dc3/tree__cmd_8cpp.html#a825c17a2dd5be07f4ff672f799a26630", null ],
    [ "InitializeTrees", "d9/dc3/tree__cmd_8cpp.html#a936045bf466edc257d0a8b84808c7811", null ],
    [ "OnTick_Trees", "d9/dc3/tree__cmd_8cpp.html#a91716e26a7385ebc4cc838da245a039d", null ],
    [ "PlaceTree", "d9/dc3/tree__cmd_8cpp.html#a943fb392a1ca2eec997e04976acf2fce", null ],
    [ "PlaceTreeAtSameHeight", "d9/dc3/tree__cmd_8cpp.html#aae0d2348b670be4ef512d4b0c7344324", null ],
    [ "PlaceTreeGroupAroundTile", "d9/dc3/tree__cmd_8cpp.html#a10da09f87218632e35e291c4517d6d4b", null ],
    [ "PlaceTreeGroups", "d9/dc3/tree__cmd_8cpp.html#adbe6ff54c3d93cdc576ac5ccc4cbde75", null ],
    [ "PlaceTreesRandomly", "d9/dc3/tree__cmd_8cpp.html#a65f3e742e983737d751924e51c619587", null ],
    [ "PlantTreesOnTile", "d9/dc3/tree__cmd_8cpp.html#a55463c9ed13541b340bdd252327d5481", null ],
    [ "TerraformTile_Trees", "d9/dc3/tree__cmd_8cpp.html#a91e0942ef786380c992910d25e8e5b87", null ],
    [ "TileLoop_Trees", "d9/dc3/tree__cmd_8cpp.html#afb76385f7dfcce77b0d24754d0638aa2", null ],
    [ "TileLoopTreesAlps", "d9/dc3/tree__cmd_8cpp.html#a1a3dc73e2e6dcc15c3e853f7023a6e51", null ],
    [ "TileLoopTreesDesert", "d9/dc3/tree__cmd_8cpp.html#a20afb620e9d6164e65ba69018cc49a32", null ],
    [ "_tile_type_trees_procs", "d9/dc3/tree__cmd_8cpp.html#a1db92fe41eb6e62674ddcd96bfbb3cbc", null ],
    [ "_trees_tick_ctr", "d9/dc3/tree__cmd_8cpp.html#a296398b4ff7ff148567927f6c2ecdef6", null ],
    [ "DEFAULT_RAINFOREST_TREE_STEPS", "d9/dc3/tree__cmd_8cpp.html#a10064b0500651e1beb92d77e1dabee60", null ],
    [ "DEFAULT_TREE_STEPS", "d9/dc3/tree__cmd_8cpp.html#a55d4e8ebce8f6d1d857ef20e92893baa", null ],
    [ "EDITOR_TREE_DIV", "d9/dc3/tree__cmd_8cpp.html#a63aab7ec759ec6fe162ec898a98981b0", null ]
];
